/******************************************************************
 -------------------------------------------------------------------
File "EleKin_EleMuscCyl01.pro"
Electrostatics - Electric scalar potential v formulation
-------------------------------------------------------------------
I N P U T
---------
Global Groups : (Extension _Ele is for Electric problem)
-------------
Domain_Ele Whole electric domain (not used)
DomainCC_Ele Nonconducting regions
DomainC_Ele Conducting regions 

Function :
--------
Sig[] Conductivity [1/ohm m]

Constraint :
----------
ElectricScalarPotential Fixed electric scalar potential (classical boundary condition)

*******************************************************************/


Group {	DefineGroup[ Domain_Ele, DomainCC_Ele, DomainC_Ele, Electrode, Electrode_j ];	}

Function { DefineFunction[ Sig]; DefineFunction[ j]; DefineConstant[Length];	}

/******************************************************************
// v = v s , for all nodes
// 	n n
*******************************************************************/
FunctionSpace {
	{ Name Hgrad_v_Ele; Type Form0;
	BasisFunction {
		{ Name sn; NameOfCoef vn; Function BF_Node; Support Region[{DomainC_Ele, Electrode_j}]; Entity NodesOf[All, Not Electrode];}
		{ Name sf; NameOfCoef vf; Function BF_GroupOfNodes; Support DomainC_Ele; 
                  Entity GroupsOfNodesOf[Electrode];}
	}

	GlobalQuantity {
	  { Name V ; Type AliasOf        ; NameOfCoef vf ; }
	  { Name I ; Type AssociatedWith ; NameOfCoef vf ; }
	}
	Constraint {
		{ NameOfCoef vn; EntityType NodesOf; NameOfConstraint ElectricScalarPotential; }
		{ NameOfCoef V ;
		  EntityType GroupsOfNodesOf ; NameOfConstraint GlobalElectricPotential ; }
		{ NameOfCoef I ;
		  EntityType GroupsOfNodesOf ; NameOfConstraint GlobalElectricCurrent ; }
	}
	}
}


Formulation {
	{ Name Electrokinetics_v; Type FemEquation;
	Quantity {
		{ Name v; Type Local; NameOfSpace Hgrad_v_Ele; }
		{ Name I ; Type Global ; NameOfSpace Hgrad_v_Ele [I] ; }
		{ Name V ; Type Global ; NameOfSpace Hgrad_v_Ele [V] ; }
	}
	Equation {
		Galerkin { [ Sig[] * Dof{Grad v} , {Grad v} ]; In DomainC_Ele; Jacobian VolCyl; Integration GradGrad; }

		// Convention: j[] is the normal current density leaving the studied domain
		Galerkin { [ j[], {v} ]; In Electrode_j; Jacobian SurCyl; Integration GradGrad; }

		// Convention: Current I leaves the studied domain as well
		GlobalTerm { [ Dof{I} / Length , {V} ] ; In Electrode ; } // quantity per unit of length (2Pi for axi)

	}
	}
}

Resolution {
	{ Name EleKin_v;
	System {{ Name Sys_Ele; NameOfFormulation Electrokinetics_v; }}
	Operation {Generate[Sys_Ele]; Solve[Sys_Ele]; SaveSolution[Sys_Ele];}
	}
}

PostProcessing {
	{ Name EleKin_v; NameOfFormulation Electrokinetics_v;
	Quantity {
		{ Name v; Value {Local { [ {v} ]; In DomainC_Ele; Jacobian VolCyl; }}}
		{ Name j; Value {Local { [ -Sig[] * {Grad v} ]; In DomainC_Ele;Jacobian VolCyl; }}}
		{ Name jabs; Value {Local { [ Norm[-Sig[] * {Grad v}] ]; In DomainC_Ele;Jacobian VolCyl; }}}
		
		{ Name V ; Value { Term { [ {V} ] ; In Electrode ; } } }
		{ Name I ; Value { Term { [ {I} ] ; In Electrode ; } } }
	}
	}
}

